==> haskell-ed25519-0.0.5.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ed25519
version:              0.0.5.0
visibility:           public
id:                   ed25519-0.0.5.0-AbBojYJLzxR7ElA4311VNK
key:                  ed25519-0.0.5.0-AbBojYJLzxR7ElA4311VNK
license:              MIT
copyright:            Copyright (c) Austin Seipp 2013-2015
maintainer:           Austin Seipp <aseipp@pobox.com>
author:               Austin Seipp
homepage:             http://thoughtpolice.github.com/hs-ed25519
synopsis:             Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.

category:             Cryptography
abi:                  c04a01b245e151704be242a7d61aa8d1
exposed:              True
exposed-modules:      Crypto.Sign.Ed25519
import-dirs:          /usr/lib/ghc-9.0.1/site-local/ed25519-0.0.5.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/ed25519-0.0.5.0
hs-libraries:         HSed25519-0.0.5.0-AbBojYJLzxR7ElA4311VNK
depends:              base-4.15.0.0 bytestring-0.10.12.1 ghc-prim-0.7.0
haddock-interfaces:   /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html:         /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ed25519-0.0.5.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ed25519
version:              0.0.5.0
visibility:           public
id:                   ed25519-0.0.5.0-6yAj5y2BEF11CQnEG85jY3
key:                  ed25519-0.0.5.0-6yAj5y2BEF11CQnEG85jY3
license:              MIT
copyright:            Copyright (c) Austin Seipp 2013-2015
maintainer:           Austin Seipp <aseipp@pobox.com>
author:               Austin Seipp
homepage:             http://thoughtpolice.github.com/hs-ed25519
synopsis:             Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.

category:             Cryptography
abi:                  50fde2bdd71cd5333c39cc0f08ed5dbc
exposed:              True
exposed-modules:      Crypto.Sign.Ed25519
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ed25519-0.0.5.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/ed25519-0.0.5.0
hs-libraries:         HSed25519-0.0.5.0-6yAj5y2BEF11CQnEG85jY3
depends:              base-4.15.1.0 bytestring-0.10.12.1 ghc-prim-0.7.0
haddock-interfaces:   /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html:         /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
